package com.playlet.system.service;

import java.util.List;

import com.playlet.system.domain.PlayletUserWithdrawalPassword;
import com.baomidou.mybatisplus.extension.service.IService;


/**
 * @Date: 2024-03-30 12:25
 * @Author: 但星霖
 * @Version: v1.0
 * @Description: 用户提现密码Service接口
 */
public interface IPlayletUserWithdrawalPasswordService extends IService<PlayletUserWithdrawalPassword> {
    /**
     * 查询用户提现密码
     *
     * @param id 用户提现密码主键
     * @return 用户提现密码
     */
    PlayletUserWithdrawalPassword selectPlayletUserWithdrawalPasswordById(Long id);

    /**
     * 查询用户提现密码列表
     *
     * @param playletUserWithdrawalPassword 用户提现密码
     * @return 用户提现密码集合
     */
    List<PlayletUserWithdrawalPassword> selectPlayletUserWithdrawalPasswordList(PlayletUserWithdrawalPassword playletUserWithdrawalPassword);

    /**
     * 新增用户提现密码
     *
     * @param playletUserWithdrawalPassword 用户提现密码
     * @return 结果
     */
    int insertPlayletUserWithdrawalPassword(PlayletUserWithdrawalPassword playletUserWithdrawalPassword);

    /**
     * 修改用户提现密码
     *
     * @param playletUserWithdrawalPassword 用户提现密码
     * @return 结果
     */
    int updatePlayletUserWithdrawalPassword(PlayletUserWithdrawalPassword playletUserWithdrawalPassword);

    /**
     * 批量删除用户提现密码
     *
     * @param ids 需要删除的用户提现密码主键集合
     * @return 结果
     */
    int deletePlayletUserWithdrawalPasswordByIds(String ids);

    /**
     * 删除用户提现密码信息
     *
     * @param id 用户提现密码主键
     * @return 结果
     */
    int deletePlayletUserWithdrawalPasswordById(Long id);

    Boolean validatePassword(PlayletUserWithdrawalPassword password);
}